﻿using MindFusion.Charting;
using MindFusion.Drawing;

using Brush = MindFusion.Drawing.Brush;
using LayoutAlignment = MindFusion.Charting.Components.LayoutAlignment;


namespace Tutorial2
{
	public partial class MainPage : ContentPage
	{
		int count = 0;

		public MainPage()
		{
			InitializeComponent();
		}

		async void OnAppearing(object sender, EventArgs e)
		{
			var stockPrices = await FetchStockPrices("ACME");

			// a series of daily opening prices
			chart.Series.Add(
				new MySeries(stockPrices, PriceType.Open));

			// a series of daily closing prices
			chart.Series.Add(
				new MySeries(stockPrices, PriceType.Close));

			// a series of daily min prices
			chart.Series.Add(
				new MySeries(stockPrices, PriceType.Low));

			// a series of daily max prices
			chart.Series.Add(
				new MySeries(stockPrices, PriceType.High));

			// assign different colors to each series
			chart.Theme.CommonSeriesFills = new List<Brush>
			{
				new SolidBrush(Colors.Yellow),
				new SolidBrush(Colors.LightBlue),
				new SolidBrush(Colors.Red),
				new SolidBrush(Colors.Green)
			};

			// customize axis appearance
			chart.Title = "ACME stock price weekly";
			chart.YAxis.MinValue = 0;
			chart.YAxis.Title = "stock price in USD";
			chart.XAxis.Title = "";
			chart.ShowXCoordinates = false;
			chart.ShowXTicks = false;
			chart.LegendHorizontalAlignment = LayoutAlignment.Far;
		}

		async Task<List<StockPrice>> FetchStockPrices(string name)
		{
			// pretend we are calling a web service, returning
			// stock price statistics for last 7 days
			return await Task.Run(() =>
			{
				var random = new Random();
				var date = DateTime.Now.AddDays(-8);

				var prices = new List<StockPrice>();
				for (int i = 0; i < 7; i++)
				{
					date = date.AddDays(1);

					double open = 200 + 500 * random.NextDouble();
					double close = open + 50 * (0.5 - random.NextDouble());
					double low = Math.Min(open, close) - 50 * random.NextDouble();
					double high = Math.Max(open, close) + 50 * random.NextDouble();

					prices.Add(
						new StockPrice(open, close, low, high, date));
				}
				return prices;
			});
		}
	}
}
