﻿using System.Collections.ObjectModel;

using MindFusion.Charting;
using MindFusion.Drawing;

using Brush = MindFusion.Drawing.Brush;
using LayoutAlignment = MindFusion.Charting.Components.LayoutAlignment;


namespace Tutorial3
{
	public partial class MainPage : ContentPage
	{
		int count = 0;

		public MainPage()
		{
			InitializeComponent();
		}

		async void OnAppearing(object sender, EventArgs e)
		{
			var stockPrices = await FetchStockPrices("ACME");

			// a series of daily opening prices
			chart.Series.Add(
				new MySeries(stockPrices, PriceType.Open));

			// a series of daily closing prices
			chart.Series.Add(
				new MySeries(stockPrices, PriceType.Close));

			// assign different colors to each series
			chart.Theme.CommonSeriesFills = new List<Brush>
			{
				new SolidBrush(Colors.Yellow),
				new SolidBrush(Colors.LightBlue)
			};

			// display min and max prices as a line chart
			var minMaxSeries = new ObservableCollection<Series>
			{
				new MySeries(stockPrices, PriceType.Low),
				new MySeries(stockPrices, PriceType.High)
			};

			var minMaxRenderer = new LineRenderer(minMaxSeries);
			minMaxRenderer.SeriesStyle = new PerSeriesStyle
			{
				Strokes = new List<Brush>
				{
					new SolidBrush(Colors.Red),
					new SolidBrush(Colors.Green)
				},
				Fills = new List<Brush>
				{
					new SolidBrush(Colors.Red),
					new SolidBrush(Colors.Green)
				},
				StrokeThicknesses = new List<double> { 4 }
			};
			chart.Plot.SeriesRenderers.Add(minMaxRenderer);
			chart.LegendRenderer.Content.Add(minMaxRenderer);

			// customize axis appearance
			chart.Title = "ACME stock price weekly";
			chart.YAxis.MinValue = 0;
			chart.YAxis.Title = "stock price in USD";
			chart.XAxis.Title = "";
			chart.ShowXCoordinates = false;
			chart.ShowXTicks = false;
			chart.LegendHorizontalAlignment = LayoutAlignment.Far;
		}

		async Task<List<StockPrice>> FetchStockPrices(string name)
		{
			// pretend we are calling a web service, returning
			// stock price statistics for last 7 days
			return await Task.Run(() =>
			{
				var random = new Random();
				var date = DateTime.Now.AddDays(-8);

				var prices = new List<StockPrice>();
				for (int i = 0; i < 7; i++)
				{
					date = date.AddDays(1);

					double open = 200 + 500 * random.NextDouble();
					double close = open + 50 * (0.5 - random.NextDouble());
					double low = Math.Min(open, close) - 50 * random.NextDouble();
					double high = Math.Max(open, close) + 50 * random.NextDouble();

					prices.Add(
						new StockPrice(open, close, low, high, date));
				}
				return prices;
			});
		}
	}
}
